@@ -276,6 +276,14 @@ class BeamBasePipelineOperator(BaseOperator, BeamDataflowMixin, ABC):
             is_dataflow_job_id_exist_callback,
         )
 
+    @property
+    def extra_links_params(self) -> dict[str, Any]:
+        return {
+            "project_id": self.dataflow_config.project_id,
+            "region": self.dataflow_config.location,
+            "job_id": self.dataflow_job_id,
+        }
+
     def execute_complete(self, context: Context, event: dict[str, Any]):
         """
         Execute when the trigger fires - returns immediately.
@@ -443,13 +451,7 @@ class BeamRunPythonPipelineOperator(BeamBasePipelineOperator):
             )
 
         location = self.dataflow_config.location or DEFAULT_DATAFLOW_LOCATION
-        DataflowJobLink.persist(
-            self,
-            context,
-            self.dataflow_config.project_id,
-            location,
-            self.dataflow_job_id,
-        )
+        DataflowJobLink.persist(context=context, region=location)
 
         if self.deferrable:
             trigger_args = {
@@ -626,13 +628,7 @@ class BeamRunJavaPipelineOperator(BeamBasePipelineOperator):
                     is_dataflow_job_id_exist_callback=self.is_dataflow_job_id_exist_callback,
                 )
             if self.dataflow_job_name and self.dataflow_config.location:
-                DataflowJobLink.persist(
-                    self,
-                    context,
-                    self.dataflow_config.project_id,
-                    self.dataflow_config.location,
-                    self.dataflow_job_id,
-                )
+                DataflowJobLink.persist(context=context)
                 if self.deferrable:
                     trigger_args = {
                         "job_id": self.dataflow_job_id,
@@ -795,14 +791,7 @@ class BeamRunGoPipelineOperator(BeamBasePipelineOperator):
                         variables=snake_case_pipeline_options,
                         process_line_callback=process_line_callback,
                     )
-
-                DataflowJobLink.persist(
-                    self,
-                    context,
-                    self.dataflow_config.project_id,
-                    self.dataflow_config.location,
-                    self.dataflow_job_id,
-                )
+                DataflowJobLink.persist(context=context)
                 if dataflow_job_name and self.dataflow_config.location:
                     self.dataflow_hook.wait_for_done(
                         job_name=dataflow_job_name,
